@@ -41,10 +41,9 @@ public:
     void askDestroy();
     virtual void cleanUpAndDelete();
 
-    void setupPackage();
-
     QString globalName() const;
     void scheduleConstraintsUpdate(Applet::Constraints c);
+    void scheduleModificationNotification();
     KConfigGroup *mainConfigGroup();
     void resetConfigurationObject();
     void globalShortcutChanged();
@@ -98,6 +97,7 @@ public:
 
     // timerEvent bookkeeping
     QBasicTimer constraintsTimer;
+    QBasicTimer *modificationsTimer;
 
     QPointer<KNotification> deleteNotification;
     QTimer *deleteNotificationTimer;
